OC.L10N.register(
    "core",
    {
    "Please select a file." : "請選擇一個檔案。",
    "File is too big" : "檔案太大",
    "The selected file is not an image." : "已選的檔案不是圖像檔案。",
    "The selected file cannot be read." : "無法讀取已選的檔案。",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 參數的設定",
    "The file was only partially uploaded" : "檔案僅部分上傳成功",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入磁碟",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "Invalid file provided" : "提供的檔案無效",
    "No image or file provided" : "未提供圖像或檔案",
    "Unknown filetype" : "檔案類型不詳",
    "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
    "Invalid image" : "圖像無效",
    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
    "No crop data provided" : "未提供剪裁數據",
    "No valid crop data provided" : "未提供有效的剪裁設定",
    "Crop is not square" : "剪裁設定不是正方形",
    "State token does not match" : "狀態權杖不相符",
    "Invalid app password" : "無效的應用程式密碼",
    "Could not complete login" : "無法完成登錄",
    "State token missing" : "找不到狀態權杖",
    "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "這個社群版的 Nextcloud 是不受支援的，且推送通知功能有限。",
    "Login" : "登入",
    "Unsupported email length (>255)" : "不受支援的電子郵件長度（>255）",
    "Password reset is disabled" : "密碼重設已停用",
    "Could not reset password because the token is expired" : "權杖已過期，無法重設密碼",
    "Could not reset password because the token is invalid" : "重設密碼權杖無效，重設失敗",
    "Password is too long. Maximum allowed length is 469 characters." : "密碼太長。 允許的最大長度為 469 個字元。",
    "%s password reset" : "%s 密碼重設",
    "Password reset" : "密碼重設",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請不用理會此電子郵件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。如果您沒有要求重設密碼的話，請不用理會此電子郵件。",
    "Reset your password" : "重設密碼",
    "The given provider is not available" : "指定的提供者不可用",
    "Task not found" : "找不到任務",
    "Internal error" : "內部錯誤",
    "Not found" : "未找到",
    "Bad request" : "請求無效",
    "Requested task type does not exist" : "請求的任務類型不存在",
    "Necessary language model provider is not available" : "沒有必要的語言模型提供者",
    "No text to image provider is available" : "沒有可用的文字轉影像提供者",
    "Image not found" : "找不到圖像",
    "No translation provider available" : "沒有可用翻譯提供者",
    "Could not detect language" : "無法檢測語言",
    "Unable to translate" : "無法翻譯",
    "Nextcloud Server" : "Nextcloud 伺服器",
    "Some of your link shares have been removed" : "部分分享連結己被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
    "The account limit of this instance is reached." : "已達此實例的帳戶數量上限。",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳戶限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
    "Learn more ↗" : "了解更多",
    "Preparing update" : "正在準備更新",
    "[%d / %d]: %s" : "[%d / %d]：%s",
    "Repair step:" : "修復步驟：",
    "Repair info:" : "修復資訊：",
    "Repair warning:" : "修復警告：",
    "Repair error:" : "修復錯誤：",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "由於更新功能已在 config.php 中設定停用，請使用命令列（command line）更新系統。",
    "Turned on maintenance mode" : "已啟用維護模式",
    "Turned off maintenance mode" : "停用維護模式",
    "Maintenance mode is kept active" : "伺服器正處於維護模式",
    "Updating database schema" : "正在更新資料庫架構",
    "Updated database" : "已更新數據庫",
    "Update app \"%s\" from App Store" : "從 App Store 更新應用程式「%s」",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的數據庫模式（若數據庫較大，可能需要一段時間）",
    "Updated \"%1$s\" to %2$s" : "已從 %1$s 更新至 %2$s",
    "Set log level to debug" : "設定記錄至除錯層級",
    "Reset log level" : "重設記錄層級",
    "Starting code integrity check" : "開始檢查程式碼完整性",
    "Finished code integrity check" : "已完成程式碼完整性檢查",
    "%s (incompatible)" : "%s （不相容）",
    "The following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
    "Already up to date" : "此版本為最新版本",
    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
    "unknown text" : "文字不詳",
    "Hello world!" : "哈囉，世界！",
    "sunny" : "晴朗的",
    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今日天氣 {weather}",
    "Hello {name}" : "哈囉 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
    "new" : "新",
    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
    "Update to {version}" : "更新到 {version}",
    "An error occurred." : "發生錯誤。",
    "Please reload the page." : "請重新整理頁面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
    "Continue to {productName}" : "前往 {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
    "Applications menu" : "應用程式選項單",
    "Apps" : "應用程式",
    "More apps" : "更多應用程式",
    "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
    "No" : "否",
    "Yes" : "是",
    "Federated user" : "聯盟用戶",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "創建分享",
    "The remote URL must include the user." : "遠端 URL 必須包含用戶。",
    "Invalid remote URL." : "無效的遠端 URL。",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
    "Please copy the link manually:" : "請手動複製連結：",
    "Custom date range" : "自訂日期範圍",
    "Pick start date" : "挑選開始日期",
    "Pick end date" : "挑選結束日期",
    "Search in date range" : "在日期範圍內搜尋",
    "Search in current app" : "在目前的應用程式中搜尋",
    "Clear search" : "清除搜尋",
    "Search everywhere" : "到處搜尋",
    "Unified search" : "統一搜尋",
    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
    "Places" : "地點",
    "Date" : "日期",
    "Today" : "今日",
    "Last 7 days" : "過去7日",
    "Last 30 days" : "過去30日",
    "This year" : "今年",
    "Last year" : "去年",
    "Search people" : "搜尋人仕",
    "People" : "人物",
    "Filter in current view" : "目前檢視裡的篩選條件",
    "Results" : "結果",
    "Load more results" : "載入更多結果",
    "Search in" : "搜尋",
    "Searching …" : "正在搜尋……",
    "Start typing to search" : "輸入文字以檢索",
    "No matching results" : "無相符結果",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介於 ${this.dateFilter.startFrom.toLocaleDateString()} 到 ${this.dateFilter.endAt.toLocaleDateString()} 間",
    "Log in" : "登入",
    "Logging in …" : "正在登入 …",
    "Server side authentication failed!" : "伺服器端認證失敗！",
    "Please contact your administrator." : "請聯絡系統管理員。",
    "Temporary error" : "暫時出現錯誤",
    "Please try again." : "請再試一次。",
    "An internal error occurred." : "發生內部錯誤。",
    "Please try again or contact your administrator." : "請重試或聯絡系統管理員。",
    "Password" : "密碼",
    "Log in to {productName}" : "登入至 {productName}",
    "Wrong login or password." : "登入名稱或密碼錯誤。",
    "This account is disabled" : "此帳戶已停用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。請耐心等待一段時間後再試。",
    "Account name or email" : "帳戶名稱或電郵地址",
    "Account name" : "帳戶名稱",
    "Log in with a device" : "使用免密碼裝置登入",
    "Login or email" : "帳戶或電子郵件",
    "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
    "Browser not supported" : "不支持該瀏覽器",
    "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
    "Your connection is not secure" : "您的連線不安全",
    "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
    "Reset password" : "重設密碼",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "如果此帳戶存在，密碼重置郵件已發送到其電郵地址。如果您沒有收到，請驗證您的電郵地址和/或帳戶，檢查您的垃圾郵件/垃圾資料夾或向您當地的管理員協助。",
    "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼電郵。請聯絡您的管理員。",
    "Password cannot be changed. Please contact your administrator." : "無法重設密碼，請聯絡管理員。",
    "Back to login" : "回到登入畫面",
    "New password" : "新密碼",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請與管理員聯繫。確定要繼續嗎？",
    "I know what I'm doing" : "我知道我在做什麼",
    "Resetting password" : "重設密碼",
    "Recommended apps" : "推薦的應用程式",
    "Loading apps …" : "正在載入應用程式…",
    "Could not fetch list of apps from the App Store." : "無法從應用程式商店抓取應用程式清單。",
    "App download or installation failed" : "應用程式下載或是安裝失敗",
    "Cannot install this app because it is not compatible" : "應用程式無法安裝，因為不相容",
    "Cannot install this app" : "無法安裝此應用程式",
    "Skip" : "略過",
    "Installing apps …" : "正在安裝應用程式…",
    "Install recommended apps" : "安裝推薦的應用程式",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
    "Distraction free note taking app." : "無干擾的筆記應用程式。",
    "Settings menu" : "設定選單",
    "Avatar of {displayName}" : "{displayName} 的虛擬化身",
    "Search contacts" : "搜尋聯絡人",
    "Reset search" : "重置搜尋",
    "Search contacts …" : "搜尋聯絡人…",
    "Could not load your contacts" : "無法載入您的聯絡人",
    "No contacts found" : "查無聯絡人",
    "Show all contacts" : "顯示所有聯絡人",
    "Install the Contacts app" : "安裝「通訊錄」應用程式",
    "Loading your contacts …" : "正在載入聯絡人…",
    "Looking for {term} …" : "正在搜尋 {term} …",
    "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
    "Search for {name} only" : "只搜尋 {name}",
    "Loading more results …" : "正在載入更多結果...",
    "Search" : "搜尋",
    "No results for {query}" : "{query} 查詢沒有結果",
    "Press Enter to start searching" : "按 Enter 開始搜尋",
    "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
    "Forgot password?" : "忘記密碼？",
    "Back to login form" : "回到登入表格",
    "Back" : "返回",
    "Login form is disabled." : "登入表格已停用",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
    "Edit Profile" : "編輯個人設定",
    "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
    "You have not added any info yet" : "您尚未新增任何資訊",
    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
    "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
    "More actions" : "更多操作",
    "This browser is not supported" : "不支援此瀏覽器",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
    "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
    "Supported versions" : "支援的版本",
    "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
    "Search {types} …" : "搜尋 {types} 中 …",
    "Choose {file}" : "選擇 {file}",
    "Choose" : "選擇",
    "Copy to {target}" : "複製到 {target}",
    "Copy" : "複製",
    "Move to {target}" : "移動到 {target}",
    "Move" : "移動",
    "OK" : "OK",
    "read-only" : "唯讀",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 個檔案相抵觸"],
    "One file conflict" : "一個檔案抵觸",
    "New Files" : "新檔案",
    "Already existing files" : "已經存在的檔案",
    "Which files do you want to keep?" : "您要保留哪一個檔案？",
    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，複製的那個檔案名稱後面會加上編號。",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "(all selected)" : "（已全選）",
    "({count} selected)" : "（已選擇 {count} 項）",
    "Error loading file exists template" : "載入已存在的模板時發生錯誤",
    "Saving …" : "儲存中 ...",
    "seconds ago" : "幾秒前",
    "Connection to server lost" : "伺服器連線中斷",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
    "Add to a project" : "加到專案",
    "Show details" : "顯示細節",
    "Hide details" : "隱藏細節",
    "Rename project" : "重新命名專案",
    "Failed to rename the project" : "重新命名專案失敗",
    "Failed to create a project" : "建立專案失敗",
    "Failed to add the item to the project" : "新增項目至專案時失敗",
    "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
    "Type to search for existing projects" : "搜尋現有專案",
    "New in" : "新加入",
    "View changelog" : "檢視版本更新紀錄",
    "Very weak password" : "密碼安全性極弱",
    "Weak password" : "密碼安全性弱",
    "So-so password" : "密碼安全性普通",
    "Good password" : "密碼安全性佳",
    "Strong password" : "密碼強度極佳",
    "No action available" : "沒有可用的操作",
    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
    "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
    "Email length is at max (255)" : "電子郵件已達到最大長度（255 個字元）",
    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Collaborative tags" : "協作標籤",
    "No tags found" : "查無標籤",
    "Personal" : "個人",
    "Accounts" : "帳戶",
    "Admin" : "管理",
    "Help" : "說明",
    "Access forbidden" : "存取被拒",
    "Profile not found" : "找不到個人資料",
    "The profile does not exist." : "個人資料不存在",
    "Back to %s" : "回到 %s",
    "Page not found" : "沒有找到頁面",
    "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無法查看它。",
    "Too many requests" : "太多要求",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
    "Error" : "錯誤",
    "Previous" : "上一個",
    "Internal Server Error" : "內部伺服器錯誤",
    "The server was unable to complete your request." : "伺服器無法完成你的請求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果此問題重複發生，請寄送技術資訊給管理員。",
    "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節",
    "For more details see the documentation ↗." : "要取得更多細節資訊，請參閱說明書 ↗。",
    "Technical details" : "技術細節",
    "Remote Address: %s" : "遠端位置：%s",
    "Request ID: %s" : "請求編號：%s",
    "Type: %s" : "類型：%s",
    "Code: %s" : "代碼：%s",
    "Message: %s" : "訊息：%s",
    "File: %s" : "檔案：%s",
    "Line: %s" : "行數：%s",
    "Trace" : "追蹤",
    "Security warning" : "安全性警示",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
    "Create an <strong>admin account</strong>" : "新增<strong>管理員賬號</strong>",
    "Show password" : "顯示密碼",
    "Toggle password visibility" : "切換密碼可見性",
    "Storage & database" : "儲存空間和數據庫",
    "Data folder" : "資料儲存位置",
    "Configure the database" : "設定數據庫",
    "Only %s is available." : "僅 %s 可使用。",
    "Install and activate additional PHP modules to choose other database types." : "安裝並啟動相關 PHP 模組來使用其他種數據庫",
    "For more details check out the documentation." : "要取得更多細節資訊，請參閱說明書。",
    "Database account" : "數據庫帳戶",
    "Database password" : "數據庫密碼",
    "Database name" : "數據庫名稱",
    "Database tablespace" : "數據庫資料表空間",
    "Database host" : "數據庫主機",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
    "Performance warning" : "性能警告",
    "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
    "Install" : "安裝",
    "Installing …" : "正在安裝 …",
    "Need help?" : "需要協助嗎？",
    "See the documentation" : "閱讀說明文件",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝您的Nextcloud。然而，檔案 CAN_INSTALL 並未在您的config目錄中。請在您的config目錄中建立 CAN_INSTALL檔以繼續。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從您的 config 目錄中移除 CAN_INSTALL 檔案。請手動移除他。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用Javascript{linkend}然後重新整理頁面。",
    "Skip to main content" : "跳到主內容",
    "Skip to navigation of app" : "跳到應用程式導覽",
    "Go to %s" : "前往 %s",
    "Get your own free account" : "取得免費賬號",
    "Connect to your account" : "連結您的賬號",
    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的帳戶，有什麼人證在嘗試登入你的帳戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
    "App password" : "應用程式密碼",
    "Grant access" : "允許存取",
    "Alternative log in using app password" : "使用應用程式密碼來登入",
    "Account access" : "帳戶存取",
    "Currently logged in as %1$s (%2$s)." : "目前以 %1$s (%2$s) 身份登入。",
    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳戶",
    "Account connected" : "帳戶已連結",
    "Your client should now be connected!" : "客戶端應該已完成連線",
    "You can close this window." : "可以關閉此視窗",
    "This share is password-protected" : "此分享受密碼保護",
    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。 請重試或重新申請。",
    "Please type in your email address to request a temporary password" : "請輸入您的電郵地址以申請臨時密碼",
    "Email address" : "電郵地址",
    "Password sent!" : "密碼已傳送！",
    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
    "Two-factor authentication" : "雙重認證",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的賬號已啟用進階安全機制，請選擇一個雙重認證方法：",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何已啟用的雙重認證方法，請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "雙重認證已實施，但尚未在您的帳戶上對其進行配置。請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "雙重認證已實施，但尚未在您的帳戶上對其進行配置。請繼續設置雙重認證。",
    "Set up two-factor authentication" : "設定雙重認證",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "雙重認證已實施，但尚未在您的帳戶上對其進行配置。請使用一個備用驗證碼來登入或聯絡管理員。",
    "Use backup code" : "使用備用認證碼",
    "Cancel login" : "取消登入",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的賬號已啟用進階安全機制，請選擇一個供應者：",
    "Error while validating your second factor" : "驗證二階段因子發生錯誤",
    "Access through untrusted domain" : "經由不可信任的域名存取。",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請模仿 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的資訊，請見%1$s文件%2$s。",
    "App update required" : "需要更新應用程式",
    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
    "The following apps will be updated:" : "將更新以下的 APP：",
    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
    "The theme %s has been disabled." : "主題 %s 已經被停用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
    "Start update" : "開始升級",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
    "Detailed logs" : "詳細記錄檔",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過50名帳戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
    "Maintenance mode" : "維護模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
    "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
    "The user limit of this instance is reached." : "的達此實例的用戶上限。",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加用戶限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 界面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的網絡伺服器未正確設置為解析“ {url}”。可以在 {linkstart} 說明書↗{linkend} 中找到更多信息。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的網絡伺服器未正確設置為解析“ {url}”。這很可能與未更新為直接傳送此資料夾的Web伺服器配置有關。請將您的配置與Apache的“。htaccess”中提供的重寫規則或Nginx文檔中提供的重寫規則（位於{linkstart}文檔頁面↗{linkend}）進行比較。在Nginx上，通常以“ location ~”開頭的行需要更新。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的 Web 伺服器未正確設置為傳遞 .woff2 檔案。這通常是 Nginx 配置的問題。對於Nextcloud 15，需要進行調整以同時交付 .woff2 檔案。將您的 Nginx 配置與我們的{linkstart}文檔↗{linkend}中的推薦配置進行比較。",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您正在通過安全連接存取實例，但是您的實例正在生成不安全的URL。這很可能意味著您被隱藏在反向代理（reverse proxy）之後，並且覆蓋配置變量（overwrite config variables）未正確設置。請閱讀{linkstart}有關此的文檔頁面↗{linkend}。",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取。這表示 .htaccess 設定檔並未生效。我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這將讓某些功能無法正常運作，我們建議修正此項設定。",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP header “{header}” 未設置為 “ {val1}”、“ {val2}”、“{val3}”、“{val4}” 或 “{val5}”。這可能會洩漏引用資訊。請參閱 {linkstart}W3C建議↗{linkend}。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "未將 “Strict-Transport-Security” HTTP header 設置為至少“{seconds}”秒。為了增強安全性，建議按照{linkstart}安全提示↗{linkend}中的說明啟用 HSTS。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "透過 HTTP 不安全地訪問網站。強烈建議您將伺服器設置為需要 HTTPS，如{linkstart}安全提示 ↗{linkend} 中所述。如果不這樣做，一些重要的網站功能，如「複製到剪貼板」或「服務工作者」將無法使用！。",
    "Currently open" : "目前開啟",
    "Wrong username or password." : "錯誤的用戶名稱 或 密碼",
    "User disabled" : "用戶已遭停用",
    "Login with username or email" : "以用戶名稱或電郵地址登入",
    "Login with username" : "以用戶名稱登入",
    "Username or email" : "用戶名稱 或 電郵地址",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "如果此帳戶存在，密碼重置郵件已發送到其電郵地址。如果您沒有收到，請驗證您的電郵地址和/或帳戶名，檢查您的垃圾郵件/垃圾資料夾或向您當地的管理員協助。",
    "Apps and Settings" : "應用程式與設定",
    "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
    "Users" : "用戶",
    "Username" : "用戶名稱",
    "Database user" : "數據庫用戶",
    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
    "Confirm your password" : "確認密碼",
    "Confirm" : "確認",
    "App token" : "應用程式權杖",
    "Alternative log in using app token" : "使用應用程式權杖來登入",
    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。"
},
"nplurals=1; plural=0;");
